@@ -1,8 +1,8 @@
 import importlib
 import os
 
-# ignore_files = ['model_service.py','demo.py','__init__.py']
-ignore_files = ['model_service.py','__init__.py']
+ignore_files = ['model_service.py','demo.py','__init__.py']
+# ignore_files = ['model_service.py','__init__.py']
 
 def load_dir(path):
     algo_list = []
